==> jaxrs-ri-2.26-b02-src.tar.bz2: jaxrs-ri/src/javax/ws/rs/client/RxInvokerProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package javax.ws.rs.client;

import java.util.concurrent.ExecutorService;

/**
 * {@link RxInvoker} provider.
 *
 * @param <T> {@code RxInvoker} subclass type.
 * @author Pavel Bucek
 * @since 2.1
 */
public interface RxInvokerProvider<T extends RxInvoker> {

    /**
     * Find out whether current instance provides given {@link RxInvoker} subclass.
     *
     * @param clazz {@code RxInvoker} subclass.
     * @return {@code true} when this provider provides given {@code RxInvoker} subclass, {@code false} otherwise.
     */
    public boolean isProviderFor(Class<?> clazz);

    /**
     * Get {@link RxInvoker} implementation instance.
     * <p>
     * The returned instance has to be thread safe.
     *
     * @param syncInvoker {@code SyncInvoker} used to execute current request.
     * @param executorService   executor service, which should be used for executing reactive callbacks invocations.
     *                          It can be {@code null}; in that case it's up to the implementation to choose the best
     *                          {@code ExecutorService} in given environment.
     * @return instance of the {@code RxInvoker} subclass.
     */
    public T getRxInvoker(SyncInvoker syncInvoker, ExecutorService executorService);

}

==> jaxrs-ri-2.27-src.tar.bz2: jaxrs-ri/src/javax/ws/rs/client/RxInvokerProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package javax.ws.rs.client;

import java.util.concurrent.ExecutorService;

/**
 * {@link RxInvoker} provider.
 * <p>
 * {@code RxInvokerProvider} must be registered in the client runtime using {@link Client#register(Class)}.
 * It provides a way to plug-in support for other reactive implementations,
 * see {@link Invocation.Builder#rx(Class)}.
 *
 * @param <T> {@code RxInvoker} subclass type.
 * @author Pavel Bucek
 * @author Santiago Pericas-Geertsen
 * @since 2.1
 */
public interface RxInvokerProvider<T extends RxInvoker> {

    /**
     * Determine if this is a provider for the given {@link RxInvoker} subclass.
     *
     * @param clazz {@code RxInvoker} subclass.
     * @return {@code true} when this provider provides given {@code RxInvoker} subclass, {@code false} otherwise.
     */
    public boolean isProviderFor(Class<?> clazz);

    /**
     * Get {@link RxInvoker} implementation instance.
     * <p>
     * The returned instance has to be thread safe.
     *
     * @param syncInvoker     {@code SyncInvoker} used to execute current request.
     * @param executorService executor service, which should be used for executing reactive callbacks invocations.
     *                        It can be {@code null}; in that case it's up to the implementation to choose the best
     *                        {@code ExecutorService} in given environment.
     * @return instance of the {@code RxInvoker} subclass.
     * @see ClientBuilder#executorService(ExecutorService)
     */
    public T getRxInvoker(SyncInvoker syncInvoker, ExecutorService executorService);

}
